/*The unique head file need to be included*/
#include "Aspose.Cells.h"

using namespace std;

/*Folders to store source files and result files to demo*/
static StringPtr sourcePath = new String("../sourceFile/");
static StringPtr resultPath = new String("../resultFile/");

/*Check result*/
 #define EXPECT_TRUE(condition) \
		if (condition) printf("--%s,line:%d -> Ok --\n", __FUNCTION__, __LINE__); \
			 else  printf("--%s,line:%d->>>> Failed!!!! <<<<--\n", __FUNCTION__, __LINE__);

/*To avoid memory leak，we use smart pointer "intrusive_ptr" of boost,each class variable should be defined as a intrusive_ptr object*/
void HelloWorld()
{
	/*create a new workbook*/
	intrusive_ptr<IWorkbook> wb = Factory::CreateIWorkbook();

	/*get the first worksheet*/
	intrusive_ptr<IWorksheetCollection> wsc = wb->GetIWorksheets();
	intrusive_ptr<IWorksheet> ws = wsc->GetObjectByIndex(0);

	/*get cell(0,0)*/
	intrusive_ptr<ICells> cells = ws->GetICells();
	intrusive_ptr<ICell> cell = cells->GetObjectByIndex(0, 0);

	/*write "Hello World" to cell(0,0) of the first sheet*/
	intrusive_ptr<String> str = new String("Hello World!"); 
	cell->PutValue(str);
	/*save this workbook to resultFile folder*/
	wb->Save(resultPath->StringAppend(new String("book1.xlsx")));
}

void ChangeValue()
{
	/*open an existing Workbook from sourceFile folder*/
	intrusive_ptr<IWorkbook> wb = Factory::CreateIWorkbook(sourcePath->StringAppend(new String("book.xlsx")));

	/*get the first worsheet*/
	intrusive_ptr<IWorksheetCollection> wsc = wb->GetIWorksheets();
	intrusive_ptr<IWorksheet> ws = wsc->GetObjectByIndex(0);

	/*get cell(0,0)*/
	intrusive_ptr<ICells> cells = ws->GetICells();
	intrusive_ptr<ICell> cell = cells->GetObjectByIndex(0, 0);

	/*modify the value of the first cell from 100 to 200 */
	cell->PutValue(200);

	/*check value*/
	EXPECT_TRUE(cell->GetIntValue() == 200);

	/*save this workbook to resultFile folder*/
	wb->Save(resultPath->StringAppend(new String("book2.xlsx")));
}

void ValueType()
{
	/*create a new workbook*/
	intrusive_ptr<IWorkbook> wb = Factory::CreateIWorkbook();

	/*get the first worksheet*/
	intrusive_ptr<IWorksheetCollection> wsc = wb->GetIWorksheets();
	intrusive_ptr<IWorksheet> ws = wsc->GetObjectByIndex(0);

	/*get cells*/
	intrusive_ptr<ICells> cells = ws->GetICells();

	/*get cell(0,0)*/
	intrusive_ptr<ICell> cell0 = cells->GetObjectByIndex(0, 0);

	/*set DatetTime value to cell(0,0)*/
	cell0->PutValue((DateTimePtr)new DateTime(2000, 1, 1));

	/*check value*/
	EXPECT_TRUE(cell0->GetDateTimeValue()->Equals((DateTimePtr)new DateTime(2000, 1, 1)));

	/*get cell(1,0)*/
	intrusive_ptr<ICell> cell1 = cells->GetObjectByIndex(1, 0);

	/*set string type value to cell(1,0)*/
	cell1->PutValue((StringPtr)new String("20000101"));

	/*check value*/
	EXPECT_TRUE(cell1->GetStringValue()->Equals((StringPtr)new String("20000101")));

	/*get cell(2,0)*/
	intrusive_ptr<ICell> cell2 = cells->GetObjectByIndex(2, 0);

	/*set double type value to cell(2,0)*/
	cell2->PutValue(20000101.01);

	/*check value*/
	EXPECT_TRUE(cell2->GetDoubleValue() == 20000101.01);

	/*get cell(3,0)*/
	intrusive_ptr<ICell> cell3 = cells->GetObjectByIndex(3, 0);

	/*set int type value to cell(3,0)*/
	cell3->PutValue(20000101);

	/*check value*/
	EXPECT_TRUE(cell3->GetIntValue()==20000101);

	/*get cell(4,0)*/
	intrusive_ptr<ICell> cell4 = cells->GetObjectByIndex(4, 0);

	/*set bool type value to cell(4,0)*/
	cell4->PutValue(true);

	/*check value*/
	EXPECT_TRUE(cell4->GetBoolValue() == true);

	/*save this workbook to resultFile*/
	wb->Save(resultPath->StringAppend(new String("book3.xlsx")));
}

void SetStyle()
{
	/*create a new workbook and get the first worksheet*/
	intrusive_ptr<IWorkbook> wb = Factory::CreateIWorkbook();
	intrusive_ptr<IWorksheet> ws = wb->GetIWorksheets()->GetObjectByIndex(0);

	/*get cells style*/
	intrusive_ptr<IStyle> style = ws->GetICells()->GetIStyle();

	/*set font color*/
	style->GetIFont()->SetColor(System::Drawing::Color::GetGreen());

	/*set Background*/
	style->SetPattern(BackgroundType::BackgroundType_Gray12);
	style->SetBackgroundColor(System::Drawing::Color::GetRed());

	/*set Border*/
	style->SetBorder((BorderType_LeftBorder), CellBorderType_Thin, System::Drawing::Color::GetBlue());
	style->SetBorder((BorderType_RightBorder), CellBorderType_Double, System::Drawing::Color::GetGold());

	/*set string value to cell 'A1'*/
	intrusive_ptr<ICells> cells = ws->GetICells();
	intrusive_ptr<ICell> cell = cells->GetObjectByIndex(new String("A1"));
	cell->PutValue((StringPtr)new String("Text"));

	/*apply style to cell 'A1'*/
	cell->SetIStyle(style);

	/*save this workbook to resultFile*/
	wb->Save(resultPath->StringAppend(new String("book4.xlsx")));
}

void FormulaCalculate()
{
	/*create a new workbook*/
	intrusive_ptr<IWorkbook> wb = Factory::CreateIWorkbook();

	/*get the first worksheet*/
	intrusive_ptr<IWorksheetCollection> wsc = wb->GetIWorksheets();
	intrusive_ptr<IWorksheet> ws = wsc->GetObjectByIndex(0);

	/*get cells*/
	intrusive_ptr<ICells> cells = ws->GetICells();

	/*set value to cell(0,0) and cell(1,0)*/
	cells->GetObjectByIndex(0, 0)->PutValue(3);
	cells->GetObjectByIndex(1, 0)->PutValue(2);

	/*set formula*/
	cells->GetObjectByIndex(0, 1)->SetFormula(new String("=SUM(A1,A2)"));

	/*formula calculation*/
	wb->CalculateFormula();

	/*check result*/
	EXPECT_TRUE(5 == cells->GetObjectByIndex(new String("B1"))->GetIntValue());

	/*save this workbook to resultFile*/
	wb->Save(resultPath->StringAppend(new String("book5.xlsx")));
}


int main(int argc, char** argv)
{	
	StringPtr info = ICellsHelper::GetVersion();
	Console::Write(info);
        printf("\n");
	/*write "Hello World" to a cell*/
	HelloWorld();       
	/*modify the value of a cell*/
	ChangeValue();
	/*put different type of value to cells */
	ValueType();
	/*set style on a cell*/
	SetStyle();
	/*formula calculation*/
	FormulaCalculate();
}




























#if 0
#include "gtest/gtest.h"
#include <iostream>
#include "Char.h"
#include "String.h"

//#include "Aspose.Cells.h"

#include "IWorkbook.h"
#include "IWorksheet.h"
#include "ICells.h"
#include "ICell.h"
#include "IWorksheetCollection.h"
#include "Factory.h"
#include "System/IO/DirectoryInfo.h"
using namespace std;

using namespace Aspose::Cells;
using namespace Aspose::Cells::System;
using namespace Aspose::Cells::System::IO;
/*********Note********
1. link settings need configed still
2. see https://www.cnblogs.com/xudong-bupt/p/3698294.html
*********************/


int UTF8ToUnicode(const char *pmbs, wchar_t *pwcs, int size)
{
    int cnt = 0;
    // 这里 size-- 是预先除去尾零所需位置
    if (pmbs != NULL && pwcs != NULL && size-- > 0) {
        while (*pmbs != 0 && size > 0) {
            unsigned char ch = *pmbs;
            if (ch > 0x7FU) {
                int cwch = 0;
                while (ch & 0x80U) {
                    ch <<= 1;
                    cwch++;
                }
                *pwcs = *pmbs++ & (0xFFU >> cwch);
                while (--cwch > 0) {
                    *pwcs <<= 6;
                    *pwcs |= (*pmbs++ & 0x3FU);
                }
            } else {
                *pwcs = *pmbs++;
            }
            pwcs++;
            size--;
            cnt++;
        }
        *pwcs = 0;
        cnt++;
    }
    return cnt;
}

int UnicodeToUTF8(const wchar_t *pwcs, char *pmbs, int size)
{
    int cnt = 0;
    // 这里 size-- 是预先除去尾零所需位置
    if (pwcs != NULL && pmbs != NULL && size-- > 0) {
        while (*pwcs != 0 && size > 0) {
            if (*pwcs < 0x00000080U) {
                *pmbs++ = (char)*pwcs;
                size -= 1;
                cnt += 1;
            } else if (*pwcs < 0x00000800U) {
                // 剩余空间不够存放该字符
                if (size < 2) {
                    break;
                }
                *pmbs++ = (0xFFU << 6) | (*pwcs >> 6);
                *pmbs++ = 0x80U | (*pwcs & 0x3FU);
                size -= 2;
                cnt += 2;
            } else if (*pwcs < 0x00010000U) {
                // 剩余空间不够存放该字符
                if (size < 3) {
                    break;
                }
                *pmbs++ = (0xFFU << 5) | (*pwcs >> 12);
                *pmbs++ = 0x80U | ((*pwcs >> 6) & 0x3FU);
                *pmbs++ = 0x80U | (*pwcs & 0x3FU);
                size -= 3;
                cnt += 3;
            } else if (*pwcs < 0x00200000U) {
                // 剩余空间不够存放该字符
                if (size < 4) {
                    break;
                }
                *pmbs++ = (0xFFU << 4) | (*pwcs >> 18);
                *pmbs++ = 0x80U | ((*pwcs >> 12) & 0x3FU);
                *pmbs++ = 0x80U | ((*pwcs >> 6) & 0x3FU);
                *pmbs++ = 0x80U | (*pwcs & 0x3FU);
                size -= 4;
                cnt += 4;
            } else if (*pwcs < 0x04000000U) {
                // 剩余空间不够存放该字符
                if (size < 5) {
                    break;
                }
                *pmbs++ = (0xFFU << 3) | (*pwcs >> 24);
                *pmbs++ = 0x80U | ((*pwcs >> 18) & 0x3FU);
                *pmbs++ = 0x80U | ((*pwcs >> 12) & 0x3FU);
                *pmbs++ = 0x80U | ((*pwcs >> 6) & 0x3FU);
                *pmbs++ = 0x80U | (*pwcs & 0x3FU);
                size -= 5;
                cnt += 5;
            } else if (*pwcs < 0x80000000U) {
                // 剩余空间不够存放该字符
                if (size < 6) {
                    break;
                }
                *pmbs++ = (0xFFU << 2) | (*pwcs >> 30);
                *pmbs++ = 0x80U | ((*pwcs >> 24) & 0x3FU);
                *pmbs++ = 0x80U | ((*pwcs >> 18) & 0x3FU);
                *pmbs++ = 0x80U | ((*pwcs >> 12) & 0x3FU);
                *pmbs++ = 0x80U | ((*pwcs >> 6) & 0x3FU);
                *pmbs++ = 0x80U | (*pwcs & 0x3FU);
                size -= 6;
                cnt += 6;
            } else {
                // 无法识别的 Unicode 字符
                break;
            }
            pwcs++;
        }
        *pmbs = 0;
        cnt++;
    }
    return cnt;
}
//extern int char16len(Char * utf16);
int main(int argc,char* argv[])
{

    //char mbs2[] = "This utf8 中文 Pi (Π) and Sigma (Σ)";
    //wchar_t wcs2[256*2] = { 0 };
    //int ret2 = UTF8ToUnicode(mbs2, wcs2, sizeof(wcs2)/sizeof(wchar_t));
    //printf("%s\n", wcs2);
    /*
    StringPtr path = new String("/home/jusinyah/test");
    intrusive_ptr<Aspose::Cells::System::IO::DirectoryInfo> dir = new Aspose::Cells::System::IO::DirectoryInfo(path);
    intrusive_ptr<Array1D<String*>> FileNames = dir->GetFileCount("/home/jusinyah/test");
    dir->GetFileList("/home/jusinyah/test");
    */


    Char* w =  u"This utf8 中文 Pi (Π) and Sigma (Σ)";
    wchar_t* w2 = L"This utf8 中文 Pi (Π) and Sigma (Σ)";
    try{
        StringPtr FirstFile = new String("/home/jusinyah/test/First.xlsx");
        intrusive_ptr<IWorkbook> wb =Factory::CreateIWorkbook();
        wb->Save(FirstFile);

        wb =Factory::CreateIWorkbook(FirstFile);
        /*get the first worksheet*/
        intrusive_ptr<IWorksheetCollection> wsc = wb->GetIWorksheets();
        intrusive_ptr<IWorksheet> ws = wsc->GetObjectByIndex(0);

        /*get cell(0,0)*/
        intrusive_ptr<ICells> cells = ws->GetICells();
        intrusive_ptr<ICell> cell = cells->GetObjectByIndex(0, 0);

        /*write "Hello World" to cell(0,0) of the first sheet*/
        intrusive_ptr<String> str = new String("Hello World！");
        cell->PutValue(str);

        /*save this workbook to resultFile folder*/
        wb->Save(FirstFile);
    }
    catch(...)
    {
        printf("ERROR!\n");
    }
    int m = 2;
    int a = wcslen(w2);
    //int b = ustrlen(w);
    //for(int i = 100000000;i--;i>0) //test tcmalloc
    {
     //   StringPtr ss = NEW String("123");
    }
   // int len = char16len(w);
    //testing::GTEST_FLAG(output) = "xml:"; //猫聥楼猫娄聛莽聰聼忙聢聬xml莽禄聯忙聻聹忙聳聡盲禄露
    testing::InitGoogleTest(&argc,argv);
    RUN_ALL_TESTS();
{
#if  0
    cout << "         " << endl;
   // StringPtr str = NEW String("123");

    //cout<< str->charValue() << endl;
    cout << "         " << endl;

 	//intrusive_ptr<Array1D<String*>> strArr = new Array1D<String*>(3);
	//StringPtr sPtr = NEW String("1");
	//strArr->SetValue(sPtr, 0);
#endif
}
    //while(1);
    return 0;
}

#endif
